@@ -7,11 +7,14 @@ sweety.conf
 
 import importlib
 import os
-from os.path import join, expandvars, realpath
+from os.path import join, expandvars, realpath, expanduser
 
 from valuebag import ValueBag
 
 __all__ = ['settings', 'version']
+
+def expand_path(path):
+    return realpath(expandvars(expanduser(path)))
   
 class GlobalSettings(ValueBag):
     def __init__(self, d = {}):
@@ -32,7 +35,7 @@ class GlobalSettings(ValueBag):
             if mod:
                 for key in dir(mod):
                     if key == key.upper():
-                        setattr(self, key, getattr(mod, key))
+                        setattr(self, key, expand_path(getattr(mod, key)))
                 
 
 settings = GlobalSettings({
@@ -46,8 +49,11 @@ settings = GlobalSettings({
                            'ENV_PIDFILE'        : 'OPT_PIDFILE'
                            })
 
-settings.ROOT_DIR = realpath(expandvars('$VIRTUAL_ENV/..'))
-settings.SITE_DIR = join(settings.ROOT_DIR, 'site')
+settings.ROOT_DIR = expand_path('$VIRTUAL_ENV/..')
+if os.environ.has_key('OPT_SITE_DIR'):
+    settings.SITE_DIR = expand_path(os.environ['OPT_SITE_DIR'])
+else:
+    settings.SITE_DIR = join(settings.ROOT_DIR, 'site')
 settings.DATA_DIR = join(settings.SITE_DIR, 'data')
 settings.LOGS_DIR = join(settings.SITE_DIR, 'logs')
 settings.TMP_DIR = join(settings.SITE_DIR, 'tmp')
